@@ -39,7 +39,7 @@ def set_dataframe_columntypes(df):
     if 'idLead' in df:
         df['idLead'] = df['idLead'].astype('int32')
     if 'idCampaign' in df:
-        df['idCampaign'] = df['idCampaign'].astype('int8')
+        df['idCampaign'] = df['idCampaign'].apply(str)
     # if 'BulkStatus' in df:
     #     df['BulkStatus']=df['BulkStatus'].astype('str')
     #     df['BulkStatus'] = df['BulkStatus'].astype('object')
@@ -274,7 +274,6 @@ def create_company_years_column(df):
     df['YearFounded'] = df['YearFounded'].fillna(0)
     df['CompanyYears']= CurrentYear-df['YearFounded']
     df.loc[(df['CompanyYears'] < 0) | (df['CompanyYears'] > 150),'CompanyYears'] = np.nan
-    logger.info(df['CompanyYears'].value_counts())
     df = df.drop(['YearFounded'], axis=1)
     return df
 
@@ -298,14 +297,10 @@ def fill_seniority_column(df):
 
 
 def filter_countries(df, countries,fixed_filter):
-    if fixed_filter==1:
+    if fixed_filter == 1:
         logger.info(f'countries out of top 8 go to other')
         top = df['Country'].value_counts().head(8).index.tolist()
-
-        logger.info('countries out of top 10 go to other')
-        top = df['Country'].value_counts().head(10).index.tolist()
-        df.loc[~df['Country'].isin(top),'Country'] = 'other'
-
+        df.loc[~df['Country'].isin(top), 'Country'] = 'other'
     else:
         logger.info(f'Filtering the following countries: {countries}')
         df = df[df['Country'].isin(countries)]
@@ -380,7 +375,7 @@ def fill_variables(df):
         'DaysSinceFirstContact':0,
         'NumFoundingRounds':0,
         'FundingAmount':0,
-        'DaysSinceLastSeed':9999
+        'DaysSinceLastSeed':99999
     }
 
     for key in variables_dict.keys():        
@@ -388,7 +383,6 @@ def fill_variables(df):
             logger.info(f'Filling variable {key} nulls with {variables_dict[key]}')
             logger.info(df[key].isna().sum())
             df[key] = df[key].fillna(variables_dict[key])
-            logger.info(df[key].value_counts())
         else:
             logger.info(f'{key} not available to fill')
     return df
@@ -532,10 +526,8 @@ def clean_mxtype_using_dictionary(df,mx_bv_dict,mx_prob_dict):
     logger.info('Defining MXTypes')
     df['mx_bv'] = df['MXType']
     df = df.replace({'mx_bv': mx_bv_dict})
-    logger.info(f'{df.mx_bv.value_counts()}')
     df['mx_prob'] = df['MXType']
     df = df.replace( {'mx_prob': mx_prob_dict} )
-    logger.info(f'{df.mx_prob.value_counts()}')
     return df
 
 
